@@ -1,7 +1,7 @@
-from .app import app
+from .app import app, cli
 from .compiler import compiler
 
 __title__ = 'SnowLang'
 __author__ = 'SnowballSH'
 __license__ = 'MIT'
-__version__ = '0.5.1.6'
+__version__ = '0.5.1.8'
