@@ -1,15 +1,12 @@
 from ..tokens import Token
+from .keywords import kw as keywords
 
-import json
 import string
 import pathlib
+
 d = pathlib.Path(__file__).parent.absolute()
 
 
-with open(f"{d}\\keywords.json", "r") as f:
-    keywords = json.load(f)
-
-
 def lex(self) -> Token or None:
     if self.current is not None and self.current in string.ascii_letters + "_":
         iden = ""
